@@ -14,14 +14,6 @@ from wcs.services.uploadprogressrecorder import UploadProgressRecorder
 
 config_file = os.path.join(expanduser("~"), ".wcscfg")
 
-cfg = Config(config_file)
-try:
-    concurrency = int(cfg.concurrency)
-    block_size = int(cfg.block_size)
-    bput_size = int(cfg.bput_size)
-except ValueError as e:
-    error(u"Invalid value,please check .wcscfg file")
-    sys.exit()
 
 lock = Lock()
 
@@ -38,6 +30,15 @@ class MultipartUpload(object):
         self.uploadBatch = ''
         self.progress = 0
         self.recorder = None
+        self.cfg = Config(config_file)
+        try:
+            self.concurrency = int(self.cfg.concurrency)
+            self.block_size = int(self.cfg.block_size)
+            self.bput_size = int(self.cfg.bput_size)
+        except ValueError as e:
+            error(u"Invalid value,please check .wcscfg file")
+            sys.exit()
+            
 
     def __need_retry(self,code):
         if code == 500 or code == -1:
@@ -49,10 +50,10 @@ class MultipartUpload(object):
         self.path = path
         self.size = os.path.getsize(self.path)
         self.key = os.path.basename(path)
-        if self.size % block_size != 0:
-            self.blocknum = int(self.size/block_size + 1)
+        if self.size % self.block_size != 0:
+            self.blocknum = int(self.size/self.block_size + 1)
         else:
-            self.blocknum = int(self.size/block_size)
+            self.blocknum = int(self.size/self.block_size)
         self.results = []
         self.uploadBatch = upload_id or ''
         self.progress = 0
@@ -70,7 +71,7 @@ class MultipartUpload(object):
 
     def _records_parse(self, upload_id):
         records = self.recorder.get_upload_record()
-        offsetlist = [i * (block_size) for i in range(0,self.blocknum)]
+        offsetlist = [i * (self.block_size) for i in range(0,self.blocknum)]
         debug(records)
         if records:
             self.uploadBatch = records['uploadBatch']
@@ -79,15 +80,15 @@ class MultipartUpload(object):
                 record = eval(record)
                 if record['code'] == 200:
                     offsetlist.remove(record['offset'])
-                    blockid = record['offset']/block_size
+                    blockid = record['offset']/self.block_size
                     if blockid < self.blocknum - 1:
-                        self.progress += block_size
+                        self.progress += self.block_size
                     else:              
-                        self.progress += self.size - (blockid * block_size)       
+                        self.progress += self.size - (blockid * self.block_size)       
         return offsetlist
     
     def _make_bput_post(self, ctx, bputnum, bput_next):
-        url = https_check(self.__bput_url(ctx, bputnum*bput_size))
+        url = https_check(self.__bput_url(ctx, bputnum*self.bput_size))
         headers = self.__generate_headers()
         return _post(url=url, headers=headers, data=bput_next)
 
@@ -111,11 +112,11 @@ class MultipartUpload(object):
         return headers
 
     def _mlk_url(self, offset):
-        blockid = offset/block_size
+        blockid = offset/self.block_size
         if blockid < self.blocknum - 1:
-            size = block_size
+            size = self.block_size
         else:
-            size = int(self.size - (blockid * block_size))
+            size = int(self.size - (blockid * self.block_size))
         return self.__block_url(int(size), blockid), size
 
     def _make_block(self, offset):
@@ -123,12 +124,12 @@ class MultipartUpload(object):
         url = https_check(url)
         headers = self.__generate_headers()        
         try:
-            mkblk_retries = int(cfg.mkblk_retries)
+            mkblk_retries = int(self.cfg.mkblk_retries)
         except ValueError as e:
             warning('parameter mkblk_retries is invalid, so use default value 3')
             mkblk_retries = 3
         with open(self.path, 'rb') as f:
-            bput = readfile(f, offset, bput_size)
+            bput = readfile(f, offset, self.bput_size)
             blkcode, blktext,_ = _post(url=url,headers=headers, data=bput)
             while mkblk_retries and self.__need_retry(blkcode):
                 blkcode, blktext,_ = _post(url=url, headers=headers, data=bput)
@@ -141,16 +142,16 @@ class MultipartUpload(object):
     
     def _make_bput(self, f, ctx, offset):
         bputnum = 1
-        offset_next = offset + bput_size
-        bput_next = readfile(f, offset_next, bput_size)
+        offset_next = offset + self.bput_size
+        bput_next = readfile(f, offset_next, self.bput_size)
         bputcode = 200
         bputtext = {'ctx' : ctx}
         try:
-            bput_retries = int(cfg.bput_retries)
+            bput_retries = int(self.cfg.bput_retries)
         except ValueError as e:
             warning('parameter bput_retries is invalid, so use default value 3')
             bput_retries = 3
-        while bput_next and bputnum < block_size/bput_size:
+        while bput_next and bputnum < self.block_size/self.bput_size:
             bputcode, bputtext, _ = self._make_bput_post(ctx, bputnum, bput_next)
             while bput_retries and self.__need_retry(bputcode):
                 bputcode, bputtext, _ = self._make_bput_post(ctx, bputnum, bput_next)
@@ -159,7 +160,7 @@ class MultipartUpload(object):
                 return offset, bputcode, bputtext['message']
             ctx = bputtext['ctx']
             offset_next = offset + bputtext['offset']
-            bput_next = readfile(f, offset_next, bput_size)
+            bput_next = readfile(f, offset_next, self.bput_size)
             bputnum += 1
         return offset, bputcode, bputtext['ctx']
  
@@ -175,7 +176,7 @@ class MultipartUpload(object):
         return 1
 
     def _get_failoffsets(self):
-        offsetlist = [i *  int(Config.block_size) for i in range(0, self.blocknum)]
+        offsetlist = [i *  int(self.block_size) for i in range(0, self.blocknum)]
         if self.results:
             for result in self.results['upload_record']:
                 result = eval(result)
@@ -185,7 +186,7 @@ class MultipartUpload(object):
         
     def _get_blkstatus(self):
         blkstatus = []
-        for offset in [i * (block_size) for i in range(0,self.blocknum)]:
+        for offset in [i * (self.block_size) for i in range(0,self.blocknum)]:
             for result in self.results['upload_record']:
                 result = eval(result)
                 if offset == result['offset']:
@@ -194,7 +195,7 @@ class MultipartUpload(object):
 
     def _make_file(self):
         try:
-            mkfile_retries = int(cfg.mkfile_retries)
+            mkfile_retries = int(self.cfg.mkfile_retries)
         except ValueError as e:
             warning(u"parameter mkfile_retries is invalid, so use default value 3")
             mkfile_retries = 3
@@ -223,18 +224,18 @@ class MultipartUpload(object):
         else:
             debug("Now start a new multipart upload task")
             self._initial_records()
-            offsets = [i * (block_size) for i in range(0,self.blocknum)]
+            offsets = [i * (self.block_size) for i in range(0,self.blocknum)]
 
         if len(offsets) != 0:
             debug('Thare are %d offsets need to upload' % (len(offsets)))
             debug('Now start upload file blocks') 
-            if concurrency > 0:
-                pool = ThreadPool(concurrency)
+            if self.concurrency > 0:
+                pool = ThreadPool(self.concurrency)
                 pool.map(self._make_block, offsets)
                 pool.close()
                 pool.join()
                 
-            elif concurrency == 0:
+            elif self.concurrency == 0:
                 for offset in offsets:
                     self._make_block(offset)
             else:
